#
# spec file for package python-django-haystack
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-haystack
Version:        3.2.1
Release:        5.1
Summary:        Pluggable search for Django
License:        BSD-3-Clause
URL:            https://github.com/django-haystack/django-haystack
Source:         https://files.pythonhosted.org/packages/source/d/django-haystack/django-haystack-%{version}.tar.gz
# pkg_resources is broken since the flufl.lock update in Factory
# https://github.com/django-haystack/django-haystack/pull/1935
Patch1:         gh-pr-1935_importlib.patch
# PATCH-FIX-UPSTREAM https://github.com/django-haystack/django-haystack/commit/3a566a50e4963bed4fb8853eca60bc894b0b7fc5 Fix unittest assert calls for Python 3.12
Patch2:         unittest312.patch
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.2
Requires:       python-packaging
Suggests:       python-elasticsearch
Suggests:       python-pysolr >= 3.7.0
Suggests:       python-Whoosh >= 2.5.4
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 2.2}
BuildRequires:  %{python_module Whoosh >= 2.5.4}
BuildRequires:  %{python_module elasticsearch}
BuildRequires:  %{python_module geopy >= 2.0.0}
BuildRequires:  %{python_module pysolr >= 3.7.0}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module requests}
BuildRequires:  python3-GDAL
# /SECTION
%python_subpackages

%description
Pluggable search for Django.

%prep
%autosetup -n django-haystack-%{version} -p1
sed -i 's:==:>=:' setup.py

# This causes errors with pytest
sed -i '/django.setup()/d' test_haystack/__init__.py
echo 'import django; django.setup()' > conftest.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export DJANGO_SETTINGS_MODULE=test_haystack.settings
# elasticsearch and solr tests require running services
# test_ensure_wgs84 is broken with some GDAL issues
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}:${PWD}
$python -m pytest -rs -k 'not (elasticsearch or solr or test_ensure_wgs84)'
}

%files %{python_files}
%doc AUTHORS README.rst
%license LICENSE
%{python_sitelib}/*haystack*/

%changelog
* Thu Mar 28 2024 Max Lin <mlin@suse.com>
- Numbering patches for fix Leap15 build
* Fri Feb  9 2024 Markéta Machová <mmachova@suse.com>
- Add upstream patch unittest312.patch to fix unittest asserts
* Fri Jan 12 2024 Georg Pfuetzenreuter <georg.pfuetzenreuter@suse.com>
- Add gh-pr-1935_importlib.patch to repair DistributionNotFound
  error caused by deprecated pkg_resources APIs
* Sun Jun 25 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Sun Sep 18 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v3.2.1
  * Fix Django 4.0 compatibility
  * No changelog maintained upstream
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- Use django-codemod to make Django 4 compatible
- Remove unnecessary build dependency coverage
* Fri Dec  3 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.1.1:
  * Considerable code and CI/CD cleanup
  * Per-field configuration of Whoosh
  * Whoosh faceting and other improvements
  * ElasticSearch 7 support
  * ElasticSearch 5 .models() support
  * Minutes granularity for update_index management command
  * update_index fix
- Switch from using nose to pytest-django
- Drop {Build,}Requires on six
* Mon Feb 22 2021 John Vandenberg <jayvdb@gmail.com>
- Add Suggests for backends pysolr and elasticsearch
- Remove missing build dependency on python36-GDAL
- Remove merged django3-support.patch
- Update to v3.0
  * See https://github.com/django-haystack/django-haystack/blob/master/docs/changelog.rst
    for partial changelog since v2.8.1
- Fix 2.4.1->2.8.1 in old changelog entry
* Wed May 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- add upstream patch django3-support.patch
  * using six replace django-six
* Mon Dec  2 2019 pgajdos@suse.com
- call spec-cleaner
* Wed Nov  6 2019 pgajdos@suse.com
- do not use setup.py test
* Tue Oct  1 2019 pgajdos@suse.com
- initial version 2.8.1, needed by python-HyperKitty [SLE-7686]
